@@ -9,9 +9,7 @@ import tarfile
 import uuid
 import zipfile
 
-from typing import Any, Callable, Dict, List, Optional, Sequence, Set, Tuple, Type, Union
-
-from typing_extensions import TypeAlias
+from typing import Any, Callable, Dict, List, Literal, Optional, Sequence, Set, Tuple, Type, Union, overload
 
 from faker.exceptions import UnsupportedFeature
 
@@ -20,11 +18,11 @@ from ..python import TypesSpec
 
 localized = True
 
-csv.register_dialect("faker-csv", csv.excel, quoting=csv.QUOTE_ALL)
+csv.register_dialect("faker-csv", csv.excel, quoting=csv.QUOTE_ALL)  # type: ignore
 
 
-ColumnSpec: TypeAlias = Union[Tuple[int, str], Tuple[int, str, Dict[str, Any]]]
-DataColumns: TypeAlias = List[ColumnSpec]
+ColumnSpec = Union[Tuple[int, str], Tuple[int, str, Dict[str, Any]]]
+DataColumns = List[ColumnSpec]
 
 
 class Provider(BaseProvider):
@@ -104,6 +102,18 @@ class Provider(BaseProvider):
             return res.digest()
         return res.hexdigest()
 
+    @overload
+    def uuid4(self) -> str: ...
+
+    @overload
+    def uuid4(self, cast_to: None) -> uuid.UUID: ...
+
+    @overload
+    def uuid4(self, cast_to: Callable[[uuid.UUID], str]) -> str: ...
+
+    @overload
+    def uuid4(self, cast_to: Callable[[uuid.UUID], bytes]) -> bytes: ...
+
     def uuid4(
         self,
         cast_to: Optional[Union[Callable[[uuid.UUID], str], Callable[[uuid.UUID], bytes]]] = str,
@@ -280,14 +290,13 @@ class Provider(BaseProvider):
             raise AssertionError(
                 "`uncompressed_size` is smaller than the calculated minimum required size",
             )
+        mode: Literal["w|", "w|gz", "w|bz2", "w|xz"] = "w|"
         if compression in ["gzip", "gz"]:
-            mode = "w:gz"
+            mode = "w|gz"
         elif compression in ["bzip2", "bz2"]:
-            mode = "w:bz2"
+            mode = "w|bz2"
         elif compression in ["lzma", "xz"]:
-            mode = "w:xz"
-        else:
-            mode = "w"
+            mode = "w|xz"
 
         tar_buffer = io.BytesIO()
         remaining_size = uncompressed_size
